package model;

import view.WorldObjectDrawer;

/**
 * Defines an abstract world object
 * @author sjoerdlagarde
 */
public abstract class WorldObject {
    
    private WorldObject previousObject;
    
    public WorldObject() {
        previousObject = null;
    }
    
    /**
     * Returns the name of the object
     * @return The name of the object
     */
    public abstract String getName();    
    
    /**
     * Specifies whether or not an object blocks a locations for other object to enter
     * @return True when the object blocks a location, false otherwise
     */
    public abstract boolean blocksLocation(); 
    
    /**
     * Draws the object to the world
     * @param drawer The drawer tool used for drawing objects
     */
    public abstract void drawObject(WorldObjectDrawer drawer);
    
    /**
     * Returns the object the given object is placed on
     * @return The previous object
     */
    public WorldObject getPreviousObject() {
        return previousObject;
    }
    
    /**
     * Sets the object the given object is placed on
     * @param object The object on which the current object is placed
     */
    public void setPreviousObject(WorldObject object) {
        previousObject = object;
    }
}
