package view;

import javax.swing.JFrame;
import model.WorldModel;
import world.WorldConfiguration;

/**
 *
 * @author sjoerdlagarde
 */
public class ModelView extends JFrame {
    private static final long serialVersionUID = 1L;
    
    private WorldTab worldView;
    private ModelTab modelView;
    
    public ModelView(WorldModel model) {
        worldView = new WorldTab(model);
        modelView = new ModelTab(model);
        model.addObserver(modelView);
        
        
        TabbedView tabbedView = new TabbedView();
        tabbedView.addTab(worldView, "World", "World view");
        tabbedView.addTab(modelView, "Model", "Model messages");
        
        setTitle("World Visualization");
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(WorldConfiguration.frameDimension);
        setContentPane(tabbedView);
        pack();
        setVisible(true);
    }
    
    public void setStatusMessage(String status) {
        worldView.setStatusMessage(status);
    }
    
    /**
     * Returns the tab that contains the world view
     * @return The world view
     */
    public WorldTab getWorldView() {
        return worldView;
    }
    
    /**
     * Returns the tab that contains the model view
     * @return The model view
     */
    public ModelTab getModelView() {
        return modelView;
    }
    
}