package view;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.GridLayout;
import java.util.Observable;
import java.util.Observer;
import javax.swing.JPanel;
import model.WorldModel;
import world.WorldConfiguration;

/**
 *
 * @author sjoerdlagarde
 */
public class WorldPanel extends JPanel implements Observer {
    private static final long serialVersionUID = 1L;
    
    private WorldModel model;
    
    private int squareSize;
    private int[] dimensions;
    
    public WorldPanel(WorldModel model) {
        this.model = model;
        
        squareSize = WorldConfiguration.gridSquareSize;
        dimensions = model.getWorldDimensions();
        
        this.setLayout(new GridLayout(1,1));
        this.setBackground(Color.white);
        int preferredSizeX = WorldConfiguration.frameDimension.width-250;
        int preferredSizeY = WorldConfiguration.frameDimension.height-WorldConfiguration.gridPadding;
        this.setPreferredSize(new Dimension(preferredSizeX,preferredSizeY));
    }
    
    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        g.translate(WorldConfiguration.gridPadding, WorldConfiguration.gridPadding);

        drawGrid(g);
        drawObjects(g);
    }  
    
    /**
     * Draws the grid of the world
     * @param g The Graphics context
     */
    private void drawGrid(Graphics g) {
        int xLength = dimensions[1]*squareSize;
        int yLength = dimensions[0]*squareSize;
        
        Color oldColor = g.getColor();
        g.setColor(Color.white);
        g.fillRect(0, 0, xLength, yLength);
        g.setColor(oldColor);
        
        for ( int x=0; x<=dimensions[1]; x++ ) 
            g.drawLine(x*squareSize, 0, x*squareSize, yLength);     
        
        for ( int y=0; y<=dimensions[0]; y++ ) 
            g.drawLine(0, y*squareSize, xLength, y*squareSize);
    }
    
    /**
     * Draws the objects on the grid in the world
     * @param g The Graphics context
     */
    private void drawObjects(Graphics g) {
        WorldObjectDrawer objectDrawer = new WorldObjectDrawer(g);
        for ( int y=0; y<dimensions[0]; y++ ) {
            for ( int x=0; x<dimensions[1]; x++ ) {
                objectDrawer.setLocation(x, y);
                model.getLocation(x, y).drawObject(objectDrawer);
            }
        }
    }

    @Override
    public void update(Observable o, Object arg) {
        repaint();
    }
}
